@@ -14,6 +14,7 @@ def _get_version(v):
 
 def get_build():
     total = 0
-    for i in list(time.localtime(time.time())):
-        total += int(i)
+    for i in list(time.localtime(time.time()))[:-1]:
+        print i
+        total += (int(i) * 3)
     return total
